@@ -5,18 +5,21 @@ from robot.api.logger import librarylogger as logger
 
 # requests import
 from requests import HTTPError
-import  requests
+import requests
 from requests_toolbelt.multipart.encoder import MultipartEncoder
 
+from url_normalize import url_normalize
+
 # python imports
 import os
 from typing import List, Dict, Any
 import time
 
-from generic_camunda_client import ApiException, DeploymentWithDefinitionsDto, DeploymentDto, LockedExternalTaskDto, \
+from generic_camunda_client import ApiException, CountResultDto, DeploymentWithDefinitionsDto, DeploymentDto, \
+    LockedExternalTaskDto, \
     VariableValueDto, FetchExternalTasksDto, FetchExternalTaskTopicDto, ProcessDefinitionApi, \
     ProcessInstanceWithVariablesDto, StartProcessInstanceDto, ProcessInstanceModificationInstructionDto, \
-    ProcessInstanceApi, ProcessInstanceDto, VersionApi
+    ProcessInstanceApi, ProcessInstanceDto, VersionApi, EvaluateDecisionDto
 import generic_camunda_client as openapi_client
 
 # local imports
@@ -99,7 +102,29 @@ class CamundaLibrary:
         """
         if not url:
             raise ValueError('Cannot set camunda engine url: no url given.')
-        self._shared_resources.camunda_url = f'{url}/engine-rest'
+        self._shared_resources.camunda_url = url_normalize(f'{url}/engine-rest')
+
+    @keyword("Get Camunda URL")
+    def get_camunda_url(self) -> str:
+        return self._shared_resources.camunda_url
+
+    @keyword("Get amount of workloads")
+    def get_amount_of_workloads(self, topic: str, **kwargs) -> int:
+        """
+        Retrieves count of tasks. By default expects a topic name, but all parameters from the original endpoint
+        may be provided: https://docs.camunda.org/manual/latest/reference/rest/external-task/get-query-count/
+        """
+        with self._shared_resources.api_client as api_client:
+            api_instance = openapi_client.ExternalTaskApi(api_client)
+
+            try:
+                response: CountResultDto = api_instance.get_external_tasks_count(topic_name=topic, **kwargs)
+            except ApiException as e:
+                logger.error(f'Failed to count workload for topic "{topic}":\n{e}')
+                raise e
+
+        logger.info(f'Amount of workloads for "{topic}":\t{response.count}')
+        return response.count
 
     @keyword(name='Deploy Model From File', tags=['deployment'])
     def deploy_model_from_file(self, path_to_model):
@@ -157,8 +182,6 @@ class CamundaLibrary:
 
         fields = {
             'deployment-name': f'{os.path.basename(args[0])}',
-            'enable-duplicate-filtering': "true",
-            'deploy-changed-only': "true",
         }
 
         for file in args:
@@ -570,3 +593,25 @@ class CamundaLibrary:
                 logger.error(f'Failed to get variable {variable_name} from '
                              f'process instance {process_instance_id}:\n{e}')
         return response
+
+    @keyword("Evaluate Decision", tags=['decision'])
+    def evaluate_decision(self, key: str, variables: dict) -> list:
+        """
+        Evaluates a given decision and returns the result.
+        The input values of the decision have to be supplied with `variables`.
+
+        == Example ==
+        | ${variables} | Create Dictionary | my_input=42 |
+        | ${response} | Evaluate Decision | my_decision_table | ${variables} |
+        """
+        with self._shared_resources.api_client as api_client:
+            api_instance = openapi_client.DecisionDefinitionApi(api_client)
+            dto = CamundaResources.convert_dict_to_openapi_variables(variables)
+            try:
+                response = api_instance.evaluate_decision_by_key(
+                    key=key,
+                    evaluate_decision_dto=openapi_client.EvaluateDecisionDto(dto))
+                return [CamundaResources.convert_openapi_variables_to_dict(r)
+                        for r in response]
+            except ApiException as e:
+                logger.error(f'Failed to evaluate decision {key}:\n{e}')
